Score

Trait Score 

pub trait Score {
    // Required method
    fn score(&self, terms: &[String]) -> usize;
}
Trait for scoring search terms against a filter

Required Methods

fn score(&self, terms: &[String]) -> usize

Returns the number of search terms that match this filter

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl Score for HashProxy<String, DefaultHasher, Xor8>

Implementation of scoring for Xor filters The score denotes the number of terms from the query that are contained in the current filter

Source

fn score(&self, terms: &[String]) -> usize

Implementors