pub trait Score {
// Required method
fn score(&self, terms: &[String]) -> usize;
}Expand description
Trait for scoring search terms against a filter
Required Methods
Implementations on Foreign Types
Sourceimpl Score for HashProxy<String, DefaultHasher, Xor8>
Implementation of scoring for Xor filters
The score denotes the number of terms from the query that are contained in the current filter
impl Score for HashProxy<String, DefaultHasher, Xor8>
Implementation of scoring for Xor filters The score denotes the number of terms from the query that are contained in the current filter